Pin

Struct Pin 

pub struct Pin<Id: PinId> { /* private fields */ }
Primary Pin structure for the physical pins exposed by Vorago MCUs.

This pin structure is only used for resource management and does not do anything on its own.

Implementations

Source

impl<I: PinId> Pin<I>

pub const unsafe fn steal() -> Self

Create a new pin instance.

Safety

This circumvents ownership rules of the HAL and allows creating multiple instances of the same pin.