RxAsync

Struct RxAsync 

pub struct RxAsync(/* private fields */);
Core data structure to allow asynchronous UART reception.

If the ring buffer becomes full, data will be lost.

Implementations

Source

impl RxAsync

pub fn new(rx: Rx, queue: Consumer<'static, u8>) -> Self

Create a new asynchronous receiver.

The passed heapless::spsc::Consumer will be used to asynchronously receive data which is filled by the interrupt handler on_interrupt_rx.

pub fn stop(&mut self)

pub fn release(self) -> (Rx, Consumer<'static, u8>)