TxFuture

Struct TxFuture 

pub struct TxFuture { /* private fields */ }

Implementations

Source

impl TxFuture

pub unsafe fn new(tx: &mut Tx, data: &[u8]) -> Self

Safety

This function stores the raw pointer of the passed data slice. The user MUST ensure that the slice outlives the data structure.